@@ -368,19 +368,18 @@ class Node(BaseModel):
         *,
         input: GQL.add_model,
         given_resolver: T.Optional[ResolverType] = None,
-        upsert: bool = False,
-        # relationships_input: REL_D_INPUT = None,
+        upsert: bool = None,
     ) -> NodeModel:
         resolver = given_resolver or cls.GQL.resolver()
-        query_str = resolver.make_add_mutation_str()
+        query_str = resolver.make_add_mutation_str(include_upsert=upsert is not None)
         if not isinstance(input, cls.GQL.add_model):
             input = cls.GQL.add_model.parse_obj(input)
 
         input_d = jsonable_encoder(input)
-        debug(input_d)
-        # rel_d = cls.make_gql_d_from_rel_d_input(rel_d_input=relationships_input or {})
-        # input_d.update(rel_d)
-        variables = {"input": jsonable_encoder(input_d), "upsert": upsert}
+
+        variables = {"input": jsonable_encoder(input_d)}
+        if upsert is not None:
+            variables["upsert"] = upsert
         j = await gql(query_str=query_str, variables=variables, url=cls.GQL.url)
         node_d = j["data"][f"{cls.GQL.add_function_name}"][cls.GQL.payload_node_name][0]
         return resolver.parse_obj_nested(node_d)
