@@ -93,15 +93,20 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         s = f"{{ {self.node.GQL.payload_node_name}{self.params_and_fields()} }}"
         return s
 
-    def make_add_mutation_str(self) -> str:
+    def make_add_mutation_str(self, include_upsert: bool) -> str:
         typename = self.node.GQL.typename
         add_model_name = self.node.GQL.add_model.__name__
         add_function_name = self.node.GQL.add_function_name
         if not (self.node.GQL.add_model and add_function_name):
             raise GQLException("Add model or add function is missing")
+        upsert_str = f", $upsert: Boolean"
+        inner_upsert_str = f", upsert: $upsert"
+        if include_upsert is False:
+            upsert_str = ""
+            inner_upsert_str = ""
         s = f"""
-            mutation Add{typename}($input: [{add_model_name}!]!, $upsert: Boolean) {{
-                {add_function_name}(input: $input, upsert: $upsert) {self.make_add_query_str()}
+            mutation Add{typename}($input: [{add_model_name}!]!{upsert_str}) {{
+                {add_function_name}(input: $input{inner_upsert_str}) {self.make_add_query_str()}
             }}
         """
         return s
